"use strict";

require("@testing-library/jest-dom");
var _react = require("@testing-library/react");
var _vitest = require("vitest");
var _index = require("../index");
var _runAxeCheck = require("@instructure/ui-axe-check/lib/runAxeCheck.js");
var _jsxRuntime = require("@emotion/react/jsx-runtime");
var _InlineList, _InlineList2, _InlineList3, _InlineList4, _InlineList5;
/*
 * The MIT License (MIT)
 *
 * Copyright (c) 2015 - present Instructure, Inc.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
describe('<InlineList />', () => {
  let consoleWarningMock;
  let consoleErrorMock;
  beforeEach(() => {
    // Mocking console to prevent test output pollution and expect for messages
    consoleWarningMock = _vitest.vi.spyOn(console, 'warn').mockImplementation(() => {});
    consoleErrorMock = _vitest.vi.spyOn(console, 'error').mockImplementation(() => {});
  });
  afterEach(() => {
    consoleWarningMock.mockRestore();
    consoleErrorMock.mockRestore();
  });
  it('should render list items and filter out null/falsy children', async () => {
    (0, _react.render)(_InlineList || (_InlineList = (0, _jsxRuntime.jsxs)(_index.InlineList, {
      children: [(0, _jsxRuntime.jsx)(_index.InlineList.Item, {
        children: "List item 1"
      }), (0, _jsxRuntime.jsx)(_index.InlineList.Item, {
        children: "List item 2"
      }), (0, _jsxRuntime.jsx)(_index.InlineList.Item, {
        children: "List item 3"
      }), (0, _jsxRuntime.jsx)(_index.InlineList.Item, {
        children: "List item 4"
      }), null, false]
    })));
    const listItems = _react.screen.getAllByRole('listitem');
    expect(listItems.length).toEqual(4);
  });
  it('should render a delimiter when delimiter="pipe"', async () => {
    const _render = (0, _react.render)(_InlineList2 || (_InlineList2 = (0, _jsxRuntime.jsxs)(_index.InlineList, {
        delimiter: "pipe",
        children: [(0, _jsxRuntime.jsx)(_index.InlineList.Item, {
          children: "List item 1"
        }), (0, _jsxRuntime.jsx)(_index.InlineList.Item, {
          children: "List item 2"
        }), (0, _jsxRuntime.jsx)(_index.InlineList.Item, {
          children: "List item 3"
        }), (0, _jsxRuntime.jsx)(_index.InlineList.Item, {
          children: "List item 4"
        })]
      }))),
      container = _render.container;
    const delimiters = container.querySelectorAll('span[aria-hidden="true"]');
    expect(delimiters.length).toEqual(4);
    delimiters.forEach(delimiter => {
      expect(delimiter.getAttribute('class')).toContain('inlineListItem__delimiter');
    });
  });
  it('should warn when itemSpacing is set when delimiter is set to anything other than none', async () => {
    (0, _react.render)(_InlineList3 || (_InlineList3 = (0, _jsxRuntime.jsxs)(_index.InlineList, {
      delimiter: "pipe",
      itemSpacing: "large",
      children: [(0, _jsxRuntime.jsx)(_index.InlineList.Item, {
        children: "List item 1"
      }), (0, _jsxRuntime.jsx)(_index.InlineList.Item, {
        children: "List item 2"
      }), (0, _jsxRuntime.jsx)(_index.InlineList.Item, {
        children: "List item 3"
      }), (0, _jsxRuntime.jsx)(_index.InlineList.Item, {
        children: "List item 4"
      })]
    })));
    const warning = `Warning: [InlineList] \`itemSpacing\` has no effect inside Lists with the \`delimiter\` prop set to anything other than \`none\`.`;
    expect(consoleErrorMock.mock.calls[0][0]).toBe(warning);
  });
  it('should render an ordered list', async () => {
    (0, _react.render)(_InlineList4 || (_InlineList4 = (0, _jsxRuntime.jsxs)(_index.InlineList, {
      as: "ol",
      children: [(0, _jsxRuntime.jsx)(_index.InlineList.Item, {
        children: "List item 1"
      }), (0, _jsxRuntime.jsx)(_index.InlineList.Item, {
        children: "List item 2"
      }), (0, _jsxRuntime.jsx)(_index.InlineList.Item, {
        children: "List item 3"
      }), (0, _jsxRuntime.jsx)(_index.InlineList.Item, {
        children: "List item 4"
      })]
    })));
    const list = _react.screen.getByRole('list');
    expect(list.tagName).toBe('OL');
  });
  it('should meet a11y standards', async () => {
    const _render2 = (0, _react.render)(_InlineList5 || (_InlineList5 = (0, _jsxRuntime.jsxs)(_index.InlineList, {
        children: [(0, _jsxRuntime.jsx)(_index.InlineList.Item, {
          children: "List item 1"
        }), (0, _jsxRuntime.jsx)(_index.InlineList.Item, {
          children: "List item 2"
        }), (0, _jsxRuntime.jsx)(_index.InlineList.Item, {
          children: "List item 3"
        }), (0, _jsxRuntime.jsx)(_index.InlineList.Item, {
          children: "List item 4"
        })]
      }))),
      container = _render2.container;
    const axeCheck = await (0, _runAxeCheck.runAxeCheck)(container);
    expect(axeCheck).toBe(true);
  });
});