import { PropsWithChildren } from 'react';
import type { Spacing, WithStyleProps, ComponentStyle } from '@instructure/emotion';
import type { PropValidators, InlineListItemTheme, OtherHTMLAttributes } from '@instructure/shared-types';
type InlineListItemOwnProps = {
    /**
     * Inherits delimiter from the parent InlineList component
     */
    delimiter?: 'none' | 'pipe' | 'slash' | 'arrow';
    size?: 'small' | 'medium' | 'large';
    /**
     * Valid values are `0`, `none`, `auto`, `xxx-small`, `xx-small`, `x-small`,
     * `small`, `medium`, `large`, `x-large`, `xx-large`. Apply these values via
     * familiar CSS-like shorthand. For example: `margin="small auto large"`.
     */
    margin?: Spacing;
    /**
     * Valid values are `0`, `none`, `xxx-small`, `xx-small`, `x-small`,
     * `small`, `medium`, `large`, `x-large`, `xx-large`. Apply these values via
     * familiar CSS-like shorthand. For example: `padding="small x-large large"`.
     */
    padding?: Spacing;
    /**
     * Inherits itemSpacing from the parent InlineList component
     */
    spacing?: 'none' | 'xxx-small' | 'xx-small' | 'x-small' | 'small' | 'medium' | 'large' | 'x-large' | 'xx-large';
    /**
     * provides a reference to the underlying html root element
     */
    elementRef?: (element: Element | null) => void;
} & PropsWithChildren<unknown>;
type PropKeys = keyof InlineListItemOwnProps;
type AllowedPropKeys = Readonly<Array<PropKeys>>;
type InlineListItemProps = InlineListItemOwnProps & WithStyleProps<InlineListItemTheme, InlineListItemStyle> & OtherHTMLAttributes<InlineListItemOwnProps>;
type InlineListItemStyle = ComponentStyle<'inlineListItem' | 'delimiter'>;
declare const propTypes: PropValidators<PropKeys>;
declare const allowedProps: AllowedPropKeys;
export type { InlineListItemProps, InlineListItemStyle };
export { propTypes, allowedProps };
//# sourceMappingURL=props.d.ts.map