import React from 'react';
import type { Spacing } from '@instructure/emotion';
import type { OtherHTMLAttributes, PropValidators } from '@instructure/shared-types';
type InlineListOwnProps = {
    /**
     * Only accepts `<InlineList.Item>` as a child
     */
    children?: React.ReactNode;
    as?: 'ul' | 'ol';
    /**
     * Valid values are `0`, `none`, `auto`, `xxx-small`, `xx-small`, `x-small`,
     * `small`, `medium`, `large`, `x-large`, `xx-large`. Apply these values via
     * familiar CSS-like shorthand. For example: `margin="small auto large"`.
     */
    margin?: Spacing;
    size?: 'small' | 'medium' | 'large';
    delimiter?: 'none' | 'pipe' | 'slash' | 'arrow';
    /**
     * Sets the margin separating each ListItem.
     */
    itemSpacing?: 'none' | 'xxx-small' | 'xx-small' | 'x-small' | 'small' | 'medium' | 'large' | 'x-large' | 'xx-large';
    /**
     * provides a reference to the underlying html root element
     */
    elementRef?: (element: Element | null) => void;
};
type PropKeys = keyof InlineListOwnProps;
type AllowedPropKeys = Readonly<Array<PropKeys>>;
type InlineListProps = InlineListOwnProps & OtherHTMLAttributes<InlineListOwnProps>;
declare const propTypes: PropValidators<PropKeys>;
declare const allowedProps: AllowedPropKeys;
export type { InlineListProps };
export { propTypes, allowedProps };
//# sourceMappingURL=props.d.ts.map