import { PropsWithChildren } from 'react';
import type { Spacing, WithStyleProps, ComponentStyle } from '@instructure/emotion';
import type { PropValidators, ListItemTheme, OtherHTMLAttributes } from '@instructure/shared-types';
type ListItemOwnProps = {
    /**
     * Inherits delimiter from the parent List component.
     */
    delimiter?: 'none' | 'dashed' | 'solid';
    size?: 'small' | 'medium' | 'large';
    /**
     * Valid values are `0`, `none`, `auto`, `xxx-small`, `xx-small`, `x-small`,
     * `small`, `medium`, `large`, `x-large`, `xx-large`. Apply these values via
     * familiar CSS-like shorthand. For example: `margin="small auto large"`.
     */
    margin?: Spacing;
    /**
     * Valid values are `0`, `none`, `xxx-small`, `xx-small`, `x-small`,
     * `small`, `medium`, `large`, `x-large`, `xx-large`. Apply these values via
     * familiar CSS-like shorthand. For example: `padding="small x-large large"`.
     */
    padding?: Spacing;
    /**
     * Inherits itemSpacing from the parent List component
     */
    spacing?: 'none' | 'xxx-small' | 'xx-small' | 'x-small' | 'small' | 'medium' | 'large' | 'x-large' | 'xx-large';
    /**
     * provides a reference to the underlying html root element
     */
    elementRef?: (element: Element | null) => void;
} & PropsWithChildren<unknown>;
type PropKeys = keyof ListItemOwnProps;
type AllowedPropKeys = Readonly<Array<PropKeys>>;
type ListItemProps = ListItemOwnProps & WithStyleProps<ListItemTheme, ListItemStyle> & OtherHTMLAttributes<ListItemOwnProps>;
type ListItemStyle = ComponentStyle<'listItem'>;
declare const propTypes: PropValidators<PropKeys>;
declare const allowedProps: AllowedPropKeys;
export type { ListItemProps, ListItemStyle };
export { propTypes, allowedProps };
//# sourceMappingURL=props.d.ts.map